@@ -860,10 +860,10 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
     {
         if ($this->data !== []) {
             if (is_int($this->dataName)) {
-                return sprintf(' with data set %s', $this->dataSetAsFilterString());
+                return sprintf(' with data set #%s', $this->dataName);
             }
 
-            return sprintf(' with data set "%s"', $this->dataSetAsFilterString());
+            return sprintf(' with data set "%s"', $this->dataName);
         }
 
         return '';
@@ -1778,18 +1778,32 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
             }
         }
 
-        return new Snapshot(
-            $excludeList,
-            $backupGlobals,
-            (bool) $this->backupStaticProperties,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-        );
+        try {
+            return new Snapshot(
+                $excludeList,
+                $backupGlobals,
+                (bool) $this->backupStaticProperties,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+            );
+        } catch (Throwable $t) {
+            Event\Facade::emitter()->testPreparationFailed(
+                $this->valueObjectForEvents(),
+                Event\Code\ThrowableBuilder::from($t),
+            );
+
+            Event\Facade::emitter()->testErrored(
+                $this->valueObjectForEvents(),
+                Event\Code\ThrowableBuilder::from($t),
+            );
+
+            throw $t;
+        }
     }
 
     private function compareGlobalStateSnapshots(Snapshot $before, Snapshot $after): void
