@@ -29,7 +29,7 @@ use SebastianBergmann\Environment\Console;
  */
 final class Help
 {
-    private const LEFT_MARGIN              = '  ';
+    private const string LEFT_MARGIN       = '  ';
     private int $lengthOfLongestOptionName = 0;
     private readonly int $columnsAvailableForDescription;
     private bool $hasColor;
@@ -123,7 +123,7 @@ final class Help
                     $arg = Color::colorize('fg-green', str_pad($option['arg'], $this->lengthOfLongestOptionName));
                     $arg = preg_replace_callback(
                         '/(<[^>]+>)/',
-                        static fn ($matches) => Color::colorize('fg-cyan', $matches[0]),
+                        static fn (array $matches) => Color::colorize('fg-cyan', $matches[0]),
                         $arg,
                     );
 
@@ -198,7 +198,7 @@ final class Help
                 ['arg'    => '--disallow-test-output', 'desc' => 'Be strict about output during tests'],
                 ['arg'    => '--enforce-time-limit', 'desc' => 'Enforce time limit based on test size'],
                 ['arg'    => '--default-time-limit <sec>', 'desc' => 'Timeout in seconds for tests that have no declared size'],
-                ['arg'    => '--dont-report-useless-tests', 'desc' => 'Do not report tests that do not test anything'],
+                ['arg'    => '--do-not-report-useless-tests', 'desc' => 'Do not report tests that do not test anything'],
                 ['spacer' => ''],
 
                 ['arg'    => '--stop-on-defect', 'desc' => 'Stop after first error, failure, warning, or risky test'],
@@ -217,12 +217,26 @@ final class Help
                 ['arg'    => '--fail-on-risky', 'desc' => 'Signal failure using shell exit code when a test was considered risky'],
                 ['arg'    => '--fail-on-deprecation', 'desc' => 'Signal failure using shell exit code when a deprecation was triggered'],
                 ['arg'    => '--fail-on-phpunit-deprecation', 'desc' => 'Signal failure using shell exit code when a PHPUnit deprecation was triggered'],
+                ['arg'    => '--fail-on-phpunit-notice', 'desc' => 'Signal failure using shell exit code when a PHPUnit notice was triggered'],
+                ['arg'    => '--fail-on-phpunit-warning', 'desc' => 'Signal failure using shell exit code when a PHPUnit warning was triggered'],
                 ['arg'    => '--fail-on-notice', 'desc' => 'Signal failure using shell exit code when a notice was triggered'],
                 ['arg'    => '--fail-on-skipped', 'desc' => 'Signal failure using shell exit code when a test was skipped'],
                 ['arg'    => '--fail-on-incomplete', 'desc' => 'Signal failure using shell exit code when a test was marked incomplete'],
                 ['arg'    => '--fail-on-all-issues', 'desc' => 'Signal failure using shell exit code when an issue is triggered'],
                 ['spacer' => ''],
 
+                ['arg'    => '--do-not-fail-on-empty-test-suite', 'desc' => 'Do not signal failure using shell exit code when no tests were run'],
+                ['arg'    => '--do-not-fail-on-warning', 'desc' => 'Do not signal failure using shell exit code when a warning was triggered'],
+                ['arg'    => '--do-not-fail-on-risky', 'desc' => 'Do not signal failure using shell exit code when a test was considered risky'],
+                ['arg'    => '--do-not-fail-on-deprecation', 'desc' => 'Do not signal failure using shell exit code when a deprecation was triggered'],
+                ['arg'    => '--do-not-fail-on-phpunit-deprecation', 'desc' => 'Do not signal failure using shell exit code when a PHPUnit deprecation was triggered'],
+                ['arg'    => '--do-not-fail-on-phpunit-notice', 'desc' => 'Do not signal failure using shell exit code when a PHPUnit notice was triggered'],
+                ['arg'    => '--do-not-fail-on-phpunit-warning', 'desc' => 'Do not signal failure using shell exit code when a PHPUnit warning was triggered'],
+                ['arg'    => '--do-not-fail-on-notice', 'desc' => 'Do not signal failure using shell exit code when a notice was triggered'],
+                ['arg'    => '--do-not-fail-on-skipped', 'desc' => 'Do not signal failure using shell exit code when a test was skipped'],
+                ['arg'    => '--do-not-fail-on-incomplete', 'desc' => 'Do not signal failure using shell exit code when a test was marked incomplete'],
+                ['spacer' => ''],
+
                 ['arg'    => '--cache-result', 'desc' => 'Write test results to cache file'],
                 ['arg'    => '--do-not-cache-result', 'desc' => 'Do not write test results to cache file'],
                 ['spacer' => ''],
@@ -247,6 +261,7 @@ final class Help
                 ['arg'    => '--display-skipped', 'desc' => 'Display details for skipped tests'],
                 ['arg'    => '--display-deprecations', 'desc' => 'Display details for deprecations triggered by tests'],
                 ['arg'    => '--display-phpunit-deprecations', 'desc' => 'Display details for PHPUnit deprecations'],
+                ['arg'    => '--display-phpunit-notices', 'desc' => 'Display details for PHPUnit notices'],
                 ['arg'    => '--display-errors', 'desc' => 'Display details for errors triggered by tests'],
                 ['arg'    => '--display-notices', 'desc' => 'Display details for notices triggered by tests'],
                 ['arg'    => '--display-warnings', 'desc' => 'Display details for warnings triggered by tests'],
@@ -260,10 +275,13 @@ final class Help
                 ['spacer' => ''],
 
                 ['arg' => '--debug', 'desc' => 'Replace default progress and result output with debugging information'],
+                ['arg' => '--with-telemetry', 'desc' => 'Include telemetry information in debugging information output'],
             ],
 
             'Logging' => [
                 ['arg' => '--log-junit <file>', 'desc' => 'Write test results in JUnit XML format to file'],
+                ['arg' => '--log-otr <file>', 'desc' => 'Write test results in Open Test Reporting XML format to file'],
+                ['arg' => '--include-git-information', 'desc' => 'Include Git information in Open Test Reporting XML logfile'],
                 ['arg' => '--log-teamcity <file>', 'desc' => 'Write test results in TeamCity format to file'],
                 ['arg' => '--testdox-html <file>', 'desc' => 'Write test results in TestDox format (HTML) to file'],
                 ['arg' => '--testdox-text <file>', 'desc' => 'Write test results in TestDox format (plain text) to file'],
@@ -274,6 +292,7 @@ final class Help
 
             'Code Coverage' => [
                 ['arg' => '--coverage-clover <file>', 'desc' => 'Write code coverage report in Clover XML format to file'],
+                ['arg' => '--coverage-openclover <file>', 'desc' => 'Write code coverage report in OpenClover XML format to file'],
                 ['arg' => '--coverage-cobertura <file>', 'desc' => 'Write code coverage report in Cobertura XML format to file'],
                 ['arg' => '--coverage-crap4j <file>', 'desc' => 'Write code coverage report in Crap4J XML format to file'],
                 ['arg' => '--coverage-html <dir>', 'desc' => 'Write code coverage report in HTML format to directory'],
@@ -303,6 +322,7 @@ final class Help
             ['arg' => '--version', 'desc' => 'Prints the version and exits'],
             ['arg' => '--atleast-version <min>', 'desc' => 'Checks that version is greater than <min> and exits'],
             ['arg' => '--check-version', 'desc' => 'Checks whether PHPUnit is the latest version and exits'],
+            ['arg' => '--check-php-configuration', 'desc' => 'Checks whether PHP configuration follows best practices'],
         ];
 
         return $elements;
