@@ -7,6 +7,11 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
+use function array_pop;
+use function end;
+use PHPUnit\Framework\Attributes\Depends;
 use PHPUnit\Framework\TestCase;
 
 class StackTest extends TestCase
@@ -17,18 +22,16 @@ class StackTest extends TestCase
         $this->assertCount(0, $stack);
 
         $stack[] = 'foo';
-        $this->assertEquals('foo', \end($stack));
+        $this->assertEquals('foo', end($stack));
         $this->assertCount(1, $stack);
 
         return $stack;
     }
 
-    /**
-     * @depends testPush
-     */
+    #[Depends('testPush')]
     public function testPop(array $stack): void
     {
-        $this->assertEquals('foo', \array_pop($stack));
+        $this->assertEquals('foo', array_pop($stack));
         $this->assertCount(0, $stack);
     }
 }
